# Instalación

> pip install git+https://bitbucket.org/gentera-insumos/data-code.git

pip install twine

python setup.py sdist

twine upload dist/yastas-data-version.tar.gz

## Token 

name: __token__

password: pypi-AgEIcHlwaS5vcmcCJDlkYTZlNGI2LTY0YzMtNDkzNi1hODMyLTA2MWJkODAxYWM4ZAACKlszLCIyZTRlZThjMy02MGJhLTRjNTgtOGRlZS1iMjE5ZjA5ZmU5NDUiXQAABiD4U_heGhtl-dpO_hBwM2FYDSJDcLERJt7lVxsQhCqp6A